NumpyDataUnit
=============

.. currentmodule:: oda_api.data_products

.. autoclass:: NumpyDataUnit
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~NumpyDataUnit.decode
      ~NumpyDataUnit.encode
      ~NumpyDataUnit.from_fits_hdu
      ~NumpyDataUnit.new_hdu_from_data
      ~NumpyDataUnit.to_fits_hdu

   .. rubric:: Methods Documentation

   .. automethod:: decode
   .. automethod:: encode
   .. automethod:: from_fits_hdu
   .. automethod:: new_hdu_from_data
   .. automethod:: to_fits_hdu
